@@ -197,6 +197,7 @@ void DesktopWidget::CreateWidgets()
     qDebug() << "Creating widgets";
     int row = 0;
 
+    m_lblSIM = NULL;
     if (m_Settings->AllSIM.count() > 1){
         m_lblSIM = new QLabel(this);
         m_lblSIM->setWordWrap(false);
@@ -216,8 +217,9 @@ void DesktopWidget::CreateWidgets()
         colSpan = 1;
     }
 
+    m_lblCreditoD = NULL;
+    m_lblCredito = NULL;
     if (m_Settings->ShowCredito){
-        m_lblCreditoD = NULL;
         if (m_Settings->ShowLabels){
             m_lblCreditoD = new QLabel(this);
             m_lblCreditoD->setWordWrap(false);
@@ -234,6 +236,7 @@ void DesktopWidget::CreateWidgets()
         row++;
     }
 
+    m_lblPunti = NULL;
     if (m_Settings->ShowPunti){
         if (m_Settings->ShowLabels){
             QLabel* lbl = new QLabel(this);
@@ -252,6 +255,8 @@ void DesktopWidget::CreateWidgets()
         row++;
     }
 
+    m_CountersFrame = NULL;
+    m_CountersLayout = NULL;
     if (m_Settings->ShowCounters.count() > 0){
         m_CountersFrame = new QFrame(this);
         m_CountersFrame->setContentsMargins(0,0,0,0);
@@ -267,14 +272,20 @@ void DesktopWidget::CreateWidgets()
 
         row++;
     }
+    qDebug() << "Widgets created";
 }
 
 bool DesktopWidget::Update()
 {
+    qDebug() << "Updating";
+    if (m_Settings->Username.isEmpty() || m_Settings->Password.isEmpty())
+        return false;
+
     bool result = UpdateData();
     if (!result)
         ShowSavedData();
     CreateTimer();
+    qDebug() << "Update result:" << result;
     return result;
 }
 
@@ -450,28 +461,31 @@ void DesktopWidget::SetWidgetSize()
 
 void DesktopWidget::ShowSavedData()
 {
+    qDebug() << "Showing saved data";
     if (m_Settings->ShowCredito)
         m_lblCredito->setText(QString("%1 %2").arg(m_Settings->LastCredito, 4, 'f', 2).arg(m_Settings->LastValuta).trimmed());
     if (m_Settings->ShowPunti && m_Settings->LastSaldoPunti != NULL)
         m_lblPunti->setText(QString("%1").arg(m_Settings->LastSaldoPunti->Punti));
 
-    QLayoutItem *child;
-    while ((child = m_CountersLayout->takeAt(0)) != 0) {
-        delete child->widget();
-        delete child;
-    }
+    if (m_CountersLayout != NULL){
+        QLayoutItem *child;
+        while ((child = m_CountersLayout->takeAt(0)) != 0) {
+            delete child->widget();
+            delete child;
+        }
 
-    foreach(Counter* c, m_Settings->ShowCounters){
-        if (c->Soglie.count() > 0){
-            c->WidgetSize = m_Settings->CounterStyle;
-            CounterWidget* w = new CounterWidget(this, c, m_Settings);
-            w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
-            m_CountersLayout->addWidget(w, 0, Qt::AlignTop);
-            w->show();
+        foreach(Counter* c, m_Settings->ShowCounters){
+            if (c->Soglie.count() > 0){
+                c->WidgetSize = m_Settings->CounterStyle;
+                CounterWidget* w = new CounterWidget(this, c, m_Settings);
+                w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
+                m_CountersLayout->addWidget(w, 0, Qt::AlignTop);
+                w->show();
+            }
         }
     }
-
     SetWidgetSize();
+    qDebug() << "Saved data shown";
 }
 
 QString DesktopWidget::GetAppletId()
