@@ -33,7 +33,7 @@ class DesktopWidget : public QFrame
 {
     Q_OBJECT
 public:
-    explicit DesktopWidget(QWidget *parent = 0, QString appletId="");
+    explicit DesktopWidget(QWidget *parent = 0, QString appletId="", bool debug=false);
     ~DesktopWidget();
 
     bool x11Event(XEvent * event);
