@@ -2,6 +2,8 @@
 #include "settings.h"
 #include "desktopwidget.h"
 
+bool WidgetManager::Debug;
+
 WidgetManager::WidgetManager(QObject *parent) :
     QObject(parent)
 {
@@ -14,7 +16,7 @@ void WidgetManager::RestoreWidgets()
     if (appletIds.count() > 0){
         //Restore widgets:
         foreach(QString id, appletIds){
-            DesktopWidget* w = new DesktopWidget(NULL, id);
+            DesktopWidget* w = new DesktopWidget(NULL, id, WidgetManager::Debug);
             w->show();
         }
     }else{
@@ -32,7 +34,7 @@ void WidgetManager::receiveMessage(const QString& message)
     if (message == MESSAGE_ADD_WIDGET){
         //Create new widget:
         QList<QString> appletIds = Settings::GetAppletIds();
-        DesktopWidget* w = new DesktopWidget(NULL, "");
+        DesktopWidget* w = new DesktopWidget(NULL, "", WidgetManager::Debug);
         appletIds.append(w->GetAppletId());
         w->show();
         Settings::SaveAppletIds(appletIds);
